### Name: read.msc
### Title: Read a MSC archive file into a data.frame
### Aliases: read.msc
### Keywords: file connection utilities

### ** Examples

file <- system.file("data/A1128551.DLY",package="climate.plot")
print(file)
dat <- read.msc(file)
print(head(dat))

plot.seas.temp(dat)
plot.year(dat)

# Show how to convert from daily to monthly data
dat$yearmonth <- factor(paste(format(dat$date,"%Y-%m"),15,sep="-"))
mlydat <- data.frame(date=as.Date(levels(dat$yearmonth)))
mlydat$year <- factor(format(mlydat$date,"%Y"))
mlydat$month <- mkfact(mlydat$date,"mon")
# means for temperature data
mlydat$max_t <- as.numeric(tapply(dat$max_t, dat$yearmonth,
                                  mean,na.rm=TRUE))
mlydat$min_t <- as.numeric(tapply(dat$min_t, dat$yearmonth,
                                  mean,na.rm=TRUE))
mlydat$mean_t <- as.numeric(tapply(dat$mean_t, dat$yearmonth,
                                   mean,na.rm=TRUE))
# sums for precipitation-related data
mlydat$rain <- as.numeric(tapply(dat$rain, dat$yearmonth,
                                 sum,na.rm=TRUE))
mlydat$snow <- as.numeric(tapply(dat$snow, dat$yearmonth,
                                 sum,na.rm=TRUE))
mlydat$precip <- as.numeric(tapply(dat$precip, dat$yearmonth,
                                   sum,na.rm=TRUE))
print(head(mlydat),12)

# Show how to convert from a HLY file into daily summaries
## Not run: 
##D # this is currently shown somewhere at http://www.sfu.ca/~mwtoews/
##D hlydat <- read.msc(bzfile("HLY11_L1127800.bz2"), flags=TRUE)
##D hlydat$date <- factor(hlydat$date)
##D # sum the solar radiation for each day to find the 'total daily'
##D sumdat <- tapply(hlydat$solar, hlydat$date, sum, na.rm=TRUE)
##D dlydat <- data.frame(date=as.Date(names(sumdat)),
##D                      solar=as.numeric(sumdat))
##D # sum the number of hours without measurements
##D sumdat <- tapply(hlydat$solar, hlydat$date,
##D                  function(v)(24 - sum(!is.na(v))))
##D dlydat$na <- as.integer(sumdat)
##D # quality control to remove days with less than 4 hours missing
##D Summerland <- dlydat[dlydat$na < 4,]
##D plot.seas.param(Summerland,param="solar", col="yellow", width=5,
##D          ylab="Daily total global solar radiation (W/(m^2*day)")
## End(Not run)



